#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 charset
version:              0.3.12
visibility:           public
id:                   charset-0.3.12-3lLNinD4S6TIK7PbSnQ95b
key:                  charset-0.3.12-3lLNinD4S6TIK7PbSnQ95b
license:              BSD-3-Clause
copyright:            (c) Edward Kmett 2010-2012
maintainer:           ekmett@gmail.com
author:               Edward Kmett
stability:            Experimental
homepage:             http://github.com/ekmett/charset
synopsis:
    Fast unicode character sets based on complemented PATRICIA tries

description:
    Fast unicode character sets based on complemented PATRICIA tries.

category:             Data
abi:                  4eec992b712bbb0912c5a468f1666f76
exposed:              True
exposed-modules:
    Data.CharSet Data.CharSet.ByteSet Data.CharSet.Common
    Data.CharSet.Posix Data.CharSet.Posix.Ascii
    Data.CharSet.Posix.Unicode Data.CharSet.Unicode
    Data.CharSet.Unicode.Block Data.CharSet.Unicode.Category

import-dirs:          /usr/lib/ghc-9.6.6/site-local/charset-0.3.12
library-dirs:         /usr/lib/ghc-9.6.6/site-local/charset-0.3.12
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/charset-0.3.12
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-charset
hs-libraries:         HScharset-0.3.12-3lLNinD4S6TIK7PbSnQ95b
depends:
    array-0.5.6.0 base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    unordered-containers-0.2.20.1-GdjPUvgItW77rL1YhzClz

haddock-interfaces:   /usr/share/doc/haskell-charset/html/charset.haddock
haddock-html:         /usr/share/doc/haskell-charset/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

